@@ -17,5 +17,14 @@
 __print_funct_t svg_print_pcsw_stats
 	(struct activity *, int, int, struct svg_parm *, unsigned long long,
 	 struct record_header *);
+__print_funct_t svg_print_swap_stats
+	(struct activity *, int, int, struct svg_parm *, unsigned long long,
+	 struct record_header *);
+__print_funct_t svg_print_paging_stats
+	(struct activity *, int, int, struct svg_parm *, unsigned long long,
+	 struct record_header *);
+__print_funct_t svg_print_net_dev_stats
+	(struct activity *, int, int, struct svg_parm *, unsigned long long,
+	 struct record_header *);
 	
 #endif /* _SVG_STATS_H */
